<?php
/**
*
* @package phpBB Extension - Forum Goal
* @copyright (c) 2016 Stoker
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace stoker\forumgoal\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
* Event listener
*/
class listener implements EventSubscriberInterface
{
	protected $template;

	protected $config;

	protected $db;

	protected $user;
	
	protected $cache;

	public function __construct(\phpbb\template\template $template, \phpbb\config\config $config, \phpbb\db\driver\driver_interface $db, \phpbb\user $user, \phpbb\controller\helper $helper, \phpbb\cache\service $cache)
	{
		$this->template = $template;
		$this->config = $config;
		$this->db = $db;
		$this->user = $user;
		$this->helper = $helper;
		$this->cache 		= $cache;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.index_modify_page_title'	=> 'index_modify_page_title',
		);
	}

	public function index_modify_page_title($event)
	{
		$this->user->add_lang_ext('stoker/forumgoal', 'common');
		
		$forumgoal_enable_all = (!empty($this->config['forumgoal_enable_all']) ? true : false);
		if ($forumgoal_enable_all)
		{
			$this->template->assign_var('FORUMGOAL_ENABLE_ALL', $this->config['forumgoal_enable_all']);
			$this->template->assign_var('FORUMGOALS_DISPLAY', $this->config['forum_goals_display']);
			$this->template->assign_var('FORUMGOAL_ENABLE', $this->config['forumgoal_enable']);

			if (!empty($this->config['forum_goals_posts_enable']) && $this->config['forum_goals_posts'] > 0)
			{
				$total_posts = $this->config['num_posts'];
				$forum_goals_posts_percent = ($total_posts * 100) / $this->config['forum_goals_posts'];
				$forum_goals_posts_rest = number_format($this->config['forum_goals_posts'] - $total_posts, '0', ',', '.');
				$this->template->assign_vars(array(
					'FPG_ENABLE'					=> $this->config['forum_goals_posts_enable'],
					'FORUM_POST_GOAL'				=> number_format($this->config['forum_goals_posts'], '0', ',', '.'),
					'FORUM_POST_GOAL_TOTAL'			=> number_format($total_posts, '0', ',', '.'),
					'FORUM_POST_PERCENT'			=> round(($forum_goals_posts_percent), 1),
					'FORUM_POST_REST'				=> $forum_goals_posts_rest,
				 ));
			}

			if (!empty($this->config['forum_goals_topics_enable']) && $this->config['forum_goals_topics'] > 0)
			{
				$total_topics = $this->config['num_topics'];
				$forum_goals_topics_percent = ($total_topics * 100) / $this->config['forum_goals_topics'];
				$forum_goals_topics_rest = number_format($this->config['forum_goals_topics'] - $total_topics, '0', ',', '.');
				$this->template->assign_vars(array(
					'FTG_ENABLE'					=> $this->config['forum_goals_topics_enable'],
					'FORUM_TOPIC_GOAL'				=> number_format($this->config['forum_goals_topics'], '0', ',', '.'),
					'FORUM_TOPIC_GOAL_TOTAL'		=> number_format($total_topics, '0', ',', '.'),
					'FORUM_TOPIC_PERCENT'			=> round(($forum_goals_topics_percent), 1),
					'FORUM_TOPIC_REST'				=> $forum_goals_topics_rest,
				));
			}

			if (!empty($this->config['forum_goals_users_enable']) && $this->config['forum_goals_users'] > 0)
			{
				$total_users = $this->config['num_users'];
				$forum_goals_users_percent = ($total_users * 100) / $this->config['forum_goals_users'];
				$forum_goals_users_rest = number_format($this->config['forum_goals_users'] - $total_users, '0', ',', '.');
				$this->template->assign_vars(array(
					'FUG_ENABLE'					=> $this->config['forum_goals_users_enable'],
					'FORUM_USER_GOAL'				=> number_format($this->config['forum_goals_users'], '0', ',', '.'),
					'FORUM_USER_GOAL_TOTAL'			=> number_format($total_users, '0', ',', '.'),
					'FORUM_USER_PERCENT'			=> round(($forum_goals_users_percent), 1),
					'FORUM_USER_REST'				=> $forum_goals_users_rest,
				));
			}

			if (!empty($this->config['forum_goals_files_enable']) && $this->config['forum_goals_files'] > 0)
			{
				$total_files	= $this->config['num_files'];
				$forum_goals_files_percent = ($total_files * 100) / $this->config['forum_goals_files'];
				$forum_goals_files_rest = number_format($this->config['forum_goals_files'] - $total_files, '0', ',', '.');
				$this->template->assign_vars(array(
					'FFG_ENABLE'					=> $this->config['forum_goals_files_enable'],
					'FORUM_FILES_GOAL_TOTAL'		=> number_format($total_files, '0', ',', '.'),
					'FORUM_FILES_GOAL'				=> number_format($this->config['forum_goals_files'], '0', ',', '.'),
					'FORUM_FILES_PERCENT'			=> round(($forum_goals_files_percent), 1),
					'FORUM_FILES_REST'				=> $forum_goals_files_rest,
				));
			}

			if (!empty($this->config['forum_goals_views_enable']) && $this->config['forum_goals_views'] > 0)
			{
				if (($total_views = $this->cache->get('_fg_forum_goals_views')) === false)
				{
					$sql = 'SELECT SUM(topic_views) AS count
						FROM ' . TOPICS_TABLE . '
						WHERE topic_posts_unapproved = 0';
					$result = $this->db->sql_query($sql);
					$total_views = (int) $this->db->sql_fetchfield('count');
				// Cache for 24 hours
				$this->cache->put('_fg_forum_goals_views', $total_views, 86400);
				}

				$forum_goals_views_percent = ($total_views * 100) / $this->config['forum_goals_views'];
				$forum_goals_views_rest = number_format($this->config['forum_goals_views'] - $total_views, '0', ',', '.');
				$this->template->assign_vars(array(
					'FTVG_ENABLE'					=> $this->config['forum_goals_views_enable'],
					'TOTAL_VIEWS'					=> number_format($total_views, '0', ',', '.'),
					'FORUM_VIEW_GOAL'				=> number_format($this->config['forum_goals_views'], '0', ',', '.'),
					'FORUM_VIEW_PERCENT'			=> round(($forum_goals_views_percent), 1),
					'FORUM_VIEW_REST'				=> $forum_goals_views_rest,
				));
			}
			
			if (!empty($this->config['forum_goals_donation_enable']))
			{
				$forum_goals_donation_goal_percent = ($this->config['forum_goals_donation_total'] * 100) / $this->config['forum_goals_donation_goal'];
				$forum_goals_donation_goal_rest = $this->config['forum_goals_donation_goal'] - $this->config['forum_goals_donation_total'];
				$this->template->assign_vars(array(
					'FDG_ENABLE'					=> $this->config['forum_goals_donation_enable'],
					'DONATION_GOAL_TOTAL'			=> $this->config['forum_goals_donation_total'],
					'DONATION_GOAL_GOAL'			=> $this->config['forum_goals_donation_goal'],
					'DONATION_GOAL_PERCENT'			=> round(($forum_goals_donation_goal_percent), 1),
					'DONATION_GOAL_REST'			=> $forum_goals_donation_goal_rest,
					'DONATION_GOAL_CUR'				=> $this->config['forum_goals_donation_cur'],
				));
			}
			
			if (!empty($this->config['forum_goals_downloads_enable']) && $this->config['forum_goals_downloads'] > 0)
			{
				if (($total_downloads = $this->cache->get('_fg_forum_goals_downloads')) === false)
				{
					$sql = 'SELECT SUM(download_count) AS count
						FROM ' . ATTACHMENTS_TABLE. '
						WHERE extension = "zip"
						OR extension = "rar"';
					$result = $this->db->sql_query($sql);
					$total_downloads = (int) $this->db->sql_fetchfield('count');
				// Cache for 24 hours
				$this->cache->put('_fg_forum_goals_downloads', $total_downloads, 86400);
				}

				$forum_goals_downloads_percent = ($total_downloads * 100) / $this->config['forum_goals_downloads'];
				$forum_goals_downloads_rest = number_format($this->config['forum_goals_downloads'] - $total_downloads, '0', ',', '.');
				$this->template->assign_vars(array(
					'FDVG_ENABLE'					=> $this->config['forum_goals_downloads_enable'],
					'TOTAL_DOWNLOADS'				=> number_format($total_downloads, '0', ',', '.'),
					'FORUM_DOWNLOADS_GOAL'			=> number_format($this->config['forum_goals_downloads'], '0', ',', '.'),
					'FORUM_DOWNLOADS_PERCENT'		=> round(($forum_goals_downloads_percent), 1),
					'FORUM_DOWNLOADS_REST'			=> $forum_goals_downloads_rest,
				));
			}
		}
	}
}